@@ -17,7 +17,9 @@ def timer(time_length = False, message = False, variable = False):
     if completed_message:
       print(completed_message)
     if variable:
-      globals()[variable] = True  
+      file = open("Timer_Completed", "w")
+      file.write("True")
+      file.close()
   t = threading.Thread(target=sub_timer)
   t.start()
 def wait(time_length = False, message = False):
